@@ -8,17 +8,17 @@ use Carp ;
 use IO::Handle ;
 use Scalar::Util qw(dualvar);
 
-use IO::Compress::Base::Common 2.006 ;
-use Compress::Raw::Zlib 2.006 ;
-use IO::Compress::Gzip 2.006 ;
-use IO::Uncompress::Gunzip 2.006 ;
+use IO::Compress::Base::Common 2.009 ;
+use Compress::Raw::Zlib 2.009 ;
+use IO::Compress::Gzip 2.009 ;
+use IO::Uncompress::Gunzip 2.009 ;
 
 use strict ;
 use warnings ;
 use bytes ;
 our ($VERSION, $XS_VERSION, @ISA, @EXPORT, $AUTOLOAD);
 
-$VERSION = '2.007';
+$VERSION = '2.009';
 $XS_VERSION = $VERSION; 
 $VERSION = eval $VERSION;
 
@@ -452,7 +452,7 @@ sub inflate
 
 package Compress::Zlib ;
 
-use IO::Compress::Gzip::Constants 2.006 ;
+use IO::Compress::Gzip::Constants 2.009 ;
 
 sub memGzip($)
 {
@@ -583,7 +583,7 @@ Compress::Zlib - Interface to zlib compression library
 
     ($d, $status) = deflateInit( [OPT] ) ;
     $status = $d->deflate($input, $output) ;
-    $status = $d->flush($output [, $flush_type]) ;
+    $status = $d->flush([$flush_type]) ;
     $d->deflateParams(OPTS) ;
     $d->deflateTune(OPTS) ;
     $d->dict_adler() ;
@@ -635,8 +635,6 @@ Compress::Zlib - Interface to zlib compression library
     ZLIB_VERSION
     ZLIB_VERNUM
 
-
-
 =head1 DESCRIPTION
 
 The I<Compress::Zlib> module provides a Perl interface to the I<zlib>
@@ -808,7 +806,6 @@ documentation for details.
 
 Returns 0 on success.
 
-
 =item B<$offset = $gz-E<gt>gztell() ;>
 
 Returns the uncompressed file offset.
@@ -893,7 +890,6 @@ be used safely.
 
 =back
 
-
 =head2 Examples
 
 Here is an example script which uses the interface. It implements a
@@ -1022,7 +1018,6 @@ The C<$level> parameter defines the compression level. Valid values are
 C<Z_BEST_COMPRESSION>, and C<Z_DEFAULT_COMPRESSION>.
 If C<$level> is not specified C<Z_DEFAULT_COMPRESSION> will be used.
 
-
 =item B<$dest = uncompress($source) ;>
 
 Uncompresses C<$source>. If successful it returns the uncompressed
@@ -1039,7 +1034,6 @@ See L<IO::Deflate|IO::Deflate> and L<IO::Inflate|IO::Inflate> included with
 this distribution for an alternative interface for reading/writing RFC 1950
 files/buffers.
 
-
 =head1 Deflate Interface
 
 This section defines an interface that allows in-memory compression using
@@ -1047,7 +1041,6 @@ the I<deflate> interface provided by zlib.
 
 Here is a definition of the interface available:
 
-
 =head2 B<($d, $status) = deflateInit( [OPT] )>
 
 Initialises a deflation stream. 
@@ -1140,10 +1133,8 @@ options will take their default values.
     deflateInit( -Bufsize => 300, 
                  -Level => Z_BEST_SPEED  ) ;
 
-
 =head2 B<($out, $status) = $d-E<gt>deflate($buffer)>
 
-
 Deflates the contents of C<$buffer>. The buffer can either be a scalar
 or a scalar reference.  When finished, C<$buffer> will be
 completely processed (assuming there were no errors). If the deflation
@@ -1159,8 +1150,8 @@ As with the I<deflate> function in I<zlib>, it is not necessarily the
 case that any output will be produced by this method. So don't rely on
 the fact that C<$out> is empty for an error test.
 
-
-=head2 B<($out, $status) = $d-E<gt>flush([flush_type])>
+=head2 B<($out, $status) = $d-E<gt>flush()>
+=head2 B<($out, $status) = $d-E<gt>flush($flush_type)>
 
 Typically used to finish the deflation. Any pending output will be
 returned via C<$out>.
@@ -1218,7 +1209,6 @@ Returns the total number of compressed bytes output from deflate.
 
 =head2 Example
 
-
 Here is a trivial example of using C<deflate>. It simply reads standard
 input, deflates it and writes it to standard output.
 
@@ -1257,7 +1247,6 @@ uncompression using the I<deflate> interface provided by zlib.
 
 Here is a definition of the interface:
 
-
 =head2 B<($i, $status) = inflateInit()>
 
 Initialises an inflation stream. 
@@ -1349,7 +1338,6 @@ Any other return code means that a flush point was not found. If more
 data is available, C<inflateSync> can be called repeatedly with more
 compressed data until the flush point is found.
 
-
 =head2 B<$i-E<gt>dict_adler()>
 
 Returns the adler32 value for the dictionary.
@@ -1423,7 +1411,6 @@ These functions allow checksums to be merged.
 All the I<zlib> constants are automatically imported when you make use
 of I<Compress::Zlib>.
 
-
 =head1 SEE ALSO
 
 L<IO::Compress::Gzip>, L<IO::Uncompress::Gunzip>, L<IO::Compress::Deflate>, L<IO::Uncompress::Inflate>, L<IO::Compress::RawDeflate>, L<IO::Uncompress::RawInflate>, L<IO::Compress::Bzip2>, L<IO::Uncompress::Bunzip2>, L<IO::Compress::Lzop>, L<IO::Uncompress::UnLzop>, L<IO::Compress::Lzf>, L<IO::Uncompress::UnLzf>, L<IO::Uncompress::AnyInflate>, L<IO::Uncompress::AnyUncompress>
@@ -1434,7 +1421,6 @@ L<File::GlobMapper|File::GlobMapper>, L<Archive::Zip|Archive::Zip>,
 L<Archive::Tar|Archive::Tar>,
 L<IO::Zlib|IO::Zlib>
 
-
 For RFC 1950, 1951 and 1952 see 
 F<http://www.faqs.org/rfcs/rfc1950.html>,
 F<http://www.faqs.org/rfcs/rfc1951.html> and
@@ -1448,25 +1434,18 @@ F<http://www.zlib.org>.
 
 The primary site for gzip is F<http://www.gzip.org>.
 
-
-
-
 =head1 AUTHOR
 
 This module was written by Paul Marquess, F<pmqs@cpan.org>. 
 
-
-
 =head1 MODIFICATION HISTORY
 
 See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 1995-2007 Paul Marquess. All rights reserved.
+Copyright (c) 1995-2008 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-
-
